@@ -21,7 +21,7 @@ import sys
 import traceback
 from os.path import join
 
-import diesel
+from aspen import json
 from aspen.http import Response
 from _tornado.template import Loader, Template
 
@@ -30,17 +30,6 @@ PAGE_BREAK = chr(12)
 log = logging.getLogger('aspen.simplate')
 
 
-# Ensure some mimetypes.
-# ======================
-# The mimetypes module uses a number of system-dependent resources to compute
-# its guesses. Aspen wants to guarantee the following, apparently. See
-# https://github.com/whit537/aspen/issues/1
-
-for ext in ('py', 'sh'):
-    mimetypes.add_type('text/plain', '.'+ext)
-mimetypes.add_type('image/x-icon', '.ico')
-
-
 class LoadError(StandardError):
     """Represent a problem parsing a simplate.
     """
@@ -66,13 +55,6 @@ class Entry:
         self.quadruple = ()
 
 
-# Tornado Loader
-# ==============
-
-def startup(website):
-    website.loader = Loader(join(website.root, '.aspen'))
-
-
 # Core loader
 # ===========
 
@@ -99,14 +81,14 @@ def load_uncached(request):
     # passed in by the user as {{ expressions }} will be encoded with UTF-8 by
     # Tornado.
     
-    mimetype = mimetypes.guess_type(request.fs, 'text/plain')[0]
+    mimetype = mimetypes.guess_type(request.fs, strict=False)[0]
     if mimetype is None:
-        mimetype = request.conf.aspen.get('default_mimetype', 'text/plain')
+        mimetype = request.configuration.default_mimetype
    
-    
-    if mimetype.startswith('text/'):
-        pass #TODO exit early if there are no ^L, , {% or {{ chars.
-             # But make sure that's actually faster. I have to think it is.
+    if mimetype.startswith('text/') or mimetype == 'application/json':
+        pass # TODO Consider exiting early if there are no ^L, , {% or {{ 
+             # characters. Is this actually faster?
+             # https://github.com/whit537/aspen/issues/1
     else:
         s = lambda s: simplate.startswith(s)
         if not (s('#!') or s('"""') or s('import') or s('from')):
@@ -116,20 +98,33 @@ def load_uncached(request):
             return (mimetype, None, None, simplate) # static file; exit early
 
     simplate = simplate.replace("^L", PAGE_BREAK)
-
     npage_breaks = simplate.count(PAGE_BREAK)
-    if npage_breaks == 0:
-        script = imports = ""
-        template = simplate
-    elif npage_breaks == 1:
-        imports = ""
-        script, template = simplate.split(PAGE_BREAK)
-    elif npage_breaks == 2:
-        imports, script, template = simplate.split(PAGE_BREAK)
+
+    if mimetype == 'application/json': # special case
+        template = None
+        if npage_breaks == 0:
+            imports = ""
+            script = simplate
+        elif npage_breaks == 1:
+            imports, script = simplate.split(PAGE_BREAK)
+        else:
+            raise SyntaxError( "JSON simplate %s may have at " % request.fs
+                             + "most one page breaks; it has "
+                             , "%d." % npage_breaks
+                              )
     else:
-        raise SyntaxError( "Simplate %s may have at most two " % request.fs
-                         + "page breaks; it has %d." % npage_breaks
-                          )
+        if npage_breaks == 0:
+            script = imports = ""
+            template = simplate
+        elif npage_breaks == 1:
+            imports = ""
+            script, template = simplate.split(PAGE_BREAK)
+        elif npage_breaks == 2:
+            imports, script, template = simplate.split(PAGE_BREAK)
+        else:
+            raise SyntaxError( "Simplate %s may have at most two " % request.fs
+                             + "page breaks; it has %d." % npage_breaks
+                              )
 
 
     # Standardize newlines.
@@ -154,11 +149,12 @@ def load_uncached(request):
 
     namespace = dict()
     namespace['__file__'] = request.fs
+    namespace['website'] = request.website
     script = compile(script, request.fs, 'exec')
-    if template.strip():
+    if template is not None and template.strip():
         template = Template( template
                            , name = request.fs
-                           , loader = request.website.loader
+                           , loader = request.website.template_loader
                            , compress_whitespace = False
                             )
     else:
@@ -258,10 +254,16 @@ def handle(request, response=None):
         if template is not None:
             response.body = template.generate(**namespace)
 
-
+    
     # Set the mimetype.
     # =================
-    # Note that we guess based on the filesystem path, not the URL path.
+    # We guess based on the filesystem path, not the URL path. Also, we 
+    # special case JSON.
+   
+    if mimetype == 'application/json':
+        if not isinstance(response.body, basestring):
+            response.body = json.dumps(response.body)
+            response.headers.set('Content-Type', request.json_content_type)
     
     if response.headers.one('Content-Type') is None:
         if mimetype.startswith('text/'):
